def sum(a):
    return a[0]+a[1]+a[2]+a[3]+a[4]
def mean(t,n):
    return (t/n)
def median(a,n):
    if n%2==0:
        median1=a[n//2]
        median2=a[n//2-1]
        median=(median1+median2)/2
    else:
        median=a[n//2]
    return median
def mode(a,n):
    freq={}
    for n in a:
        freq.setdefault(n,0)
        freq[n]+=1
        mode=max(freq.values())

    return mode



from setuptools import setup

with open('README.md', 'r') as file:
    long_description = file.read()

setup(
    name='statspackage',
    version='1.1',
    description='To find Mean,Median,Mode of the given numbers',
    long_description=long_description,
    long_description_content_type='text/markdown',
    py_modules=['statspackage'],
    package_dir={'': 'src'},
    classifiers=[
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",

        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Operating System :: OS Independent",
    ],
    install_requires=[],
    url="https://github.com/Vishalkanna2001/statistics-pyt",
    author='Vishal Kanna AJK',
    author_email='vishalkanna.k@outlook.com'
)